Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/pi-hole/pi-hole.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'test/test_any_utils.py')
-rw-r--r--test/test_any_utils.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/test_any_utils.py b/test/test_any_utils.py
index 6a1146ee..5b4075d9 100644
--- a/test/test_any_utils.py
+++ b/test/test_any_utils.py
@@ -92,7 +92,7 @@ def test_getFTLAPIPort_custom(host):
def test_getFTLAPIPort_malicious(host):
"""Confirms getFTLAPIPort returns -1 if the setting in pihole-FTL.conf contains non-digits"""
host.run(
"""
echo "FTLPORT=*$ssdfsd" > /etc/pihole/pihole-FTL.conf
@@ -104,7 +104,7 @@ def test_getFTLAPIPort_malicious(host):
getFTLAPIPort
"""
)
- expected_stdout = "-1\n"
+ expected_stdout = "4711\n"
assert expected_stdout == output.stdout
@@ -92,7 +92,7 @@ def test_getFTLAPIPort_custom(host):
def test_getFTLAPIPort_malicious(host):
- """Confirms getFTLAPIPort returns -1 if the setting in pihole-FTL.conf contains non-digits"""
+ """Confirms getFTLAPIPort returns 4711 if the setting in pihole-FTL.conf contains non-digits"""
host.run(
"""